/v1/projects/{project_id}/dynamips/devices/{device_id}/ports/{port_number:d+}/nio — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /v1/projects/{project_id}/dynamips/devices/{device_id}/ports/{port_number:d+}/nio

Contents

- /v1/projects/{project_id}/dynamips/devices/{device_id}/ports/{port_number:d+}/nio
  - POST /v1/projects/{project_id}/dynamips/devices/{device_id}/ports/{port_number:d+}/nio
    - Parameters
    - Response status codes
    - Input
      - Types
        - Ethernet
        - LinuxEthernet
        - NULL
        - TAP
        - UDP
        - UNIX
        - VDE
      - Body
  - DELETE /v1/projects/{project_id}/dynamips/devices/{device_id}/ports/{port_number:d+}/nio
    - Parameters
    - Response status codes

## POST /v1/projects/{project_id}/dynamips/devices/{device_id}/ports/{port_number:d+}/nio

Add a NIO to a Dynamips device instance

### Parameters

- project_id: UUID for the project
- device_id: UUID for the instance
- port_number: Port on the device

### Response status codes

- 400: Invalid request
- 201: NIO created
- 404: Instance doesn’t exist

### Input

#### Types

##### Ethernet

Generic Ethernet Network Input/Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
ethernet_device | ✔ | string | Ethernet device name e.g. eth0
type | ✔ | enum | Possible values: nio_generic_ethernet

##### LinuxEthernet

Linux Ethernet Network Input/Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
ethernet_device | ✔ | string | Ethernet device name e.g. eth0
type | ✔ | enum | Possible values: nio_linux_ethernet

##### NULL

NULL Network Input/Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
type | ✔ | enum | Possible values: nio_null

##### TAP

TAP Network Input/Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
tap_device | ✔ | string | TAP device name e.g. tap0
type | ✔ | enum | Possible values: nio_tap

##### UDP

UDP Network Input/Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
lport | ✔ | integer | Local port
rhost | ✔ | string | Remote host
rport | ✔ | integer | Remote port
type | ✔ | enum | Possible values: nio_udp

##### UNIX

UNIX Network Input/Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
local_file | ✔ | string | path to the UNIX socket file (local)
remote_file | ✔ | string | path to the UNIX socket file (remote)
type | ✔ | enum | Possible values: nio_unix

##### VDE

VDE Network Input/Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
control_file | ✔ | string | path to the VDE control file
local_file | ✔ | string | path to the VDE control file
type | ✔ | enum | Possible values: nio_vde

#### Body

Name | Mandatory | Type | Description
--- | --- | --- | ---
mappings |  | object |
nio | ✔ | UDP, Ethernet, LinuxEthernet, TAP, UNIX, VDE, NULL |
port_settings |  | object | Ethernet switch

## DELETE /v1/projects/{project_id}/dynamips/devices/{device_id}/ports/{port_number:d+}/nio

Remove a NIO from a Dynamips device instance

### Parameters

- project_id: UUID for the project
- device_id: UUID for the instance
- port_number: Port on the device

### Response status codes

- 400: Invalid request
- 404: Instance doesn’t exist
- 204: NIO deleted

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »